% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genetic.R
\name{additive_genetic_competition}
\alias{additive_genetic_competition}
\title{Build an additive-genetic competition model}
\usage{
additive_genetic_competition(pedigree, coordinates, id, decay,
  autofill = TRUE)
}
\arguments{
\item{pedigree}{object of class 'pedigree'}

\item{coordinates}{two-column matrix-like set of row and column coordinates 
of observational units}

\item{id}{integer vector of numeric codes for observed individuals}

\item{decay}{numeric. The positive value of the decay parameter \eqn{\alpha}.
Typically 1 or 2. See Details.}

\item{autofill}{logical. If TRUE (default) it will try to fill missing rows
or columns with missing observations. Otherwise, will treat individuals as
neighbours even if they are across an empty line.}
}
\value{
A list with elements \code{pedigree}, \code{incidence.matrix}, 
  \code{structure.matrix} and \code{structure.type}, which is a string 
  indicating either \code{covariance} or \code{precision}.
}
\description{
Return incidence and structure for a \code{additive_genetic_competition}
model, given the pedigree, the spatial coordinates and codes of the
observations and the competition decay parameter.
}
\details{
\code{id} must hold the codes of observed individuals in the original 
codification. If recoding took place when building the pedigree, this 
function will handle the codes internally.
}
\examples{
dat <- data.frame(id   = 1:5,
                  sire = c(11, 11, 2, 3, 2),
                  dam  = c(12, NA, 1, 12, 1),
                  x    = c(rep(1:2, times = 2), 3),
                  y    = c(rep(1:2, each = 2), 3))
ped <- build_pedigree(1:3, data = dat)
breedR:::additive_genetic_competition(ped, coord = dat[, c('x', 'y')], dat$id, 2)
}
