% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/splines.R
\name{breedr_splines}
\alias{breedr_splines}
\title{Build a splines model}
\usage{
breedr_splines(coordinates, n.knots = NULL, autofill = TRUE,
  degree = 3, sparse = TRUE, strategy = "uniformgrid", ...)
}
\arguments{
\item{coordinates}{matrix(-like) of observation coordinates}

\item{n.knots}{numeric. Vector of length two with an integer number of knots 
in each dimension.}

\item{autofill}{logical. If \code{TRUE} (default) it will try to fill gaps in
the rows or columns. Otherwise, it will treat gaps the same way as adjacent
rows or columns.}

\item{degree}{integer. Degree of the B-spline polynomials.}

\item{sparse}{logical. If \code{TRUE} (default) the incidence matrix will be stored in 
sparse format. Current implementation ignores a value of FALSE.}

\item{strategy}{character. Strategy for placing spline knots. Only 
\code{uniformgrid} available for the moment.}

\item{...}{Not used.}
}
\value{
A list with elements \code{incidence.matrix}, \code{structure.matrix}
  and \code{structure.type}, which is a string indicating either 
  \code{covariance} or \code{precision}.
}
\description{
Given the coordinates of the observations, and the degree, this function puts
into place a sensible number of spline knots and computes the incidence 
matrix B and the covariance matrix U
}
\details{
Relies on \code{splines::splineDesign()}, which uses a C function call to 
compute the splines coefficients.

\code{sparse} matrices take less memory, but also take longer to compute 
with. This is probably convenient only for really big datasets in comparison 
with RAM size. The covariance matrix is always stored in sparse format, as it
is particularly sparse.
}
