% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{larix}
\alias{larix}
\title{Longitudinal Larix dataset}
\format{A dataframe with 11897 observations of the following variables
\itemize{
  \item{\code{self}}{   id of the tree}
  \item{\code{dad}}{    id of sire}
  \item{\code{mum}}{    id of dam}
  \item{\code{x, y}}{   coordinates (in rows/cols)}
  \item{\code{rep}}{    factor replicate with 8 levels}
  \item{\code{bl}}{     factor block with 40 levels nested within rep}
  \item{\code{yr}}{     factor (growth) year with 16 ordered levels}
  \item{\code{map}}{    mean annual precipitation}
  \item{\code{mat}}{    mean annual temperature}
  \item{\code{mi}}{     martone index}
  \item{\code{LAS}}{    phenotype LAS}
  \item{\code{DOS}}{    phenotype DOS}
}}
\description{
Repeated measurements of microdensity data along 16 years, with climatic
covariates.
}
\details{
Each one of the 8 replicate is composed of 5 incomplete blocks, which gives a
nested variable with 40 levels.
}
\examples{
library(tidyr)
library(dplyr)
library(ggplot2)
data(larix)

## N observations by year and replicate
with(larix, table(yr, rep))

## Mean response evolution by replicate
larix \%>\%
  group_by(yr, rep) \%>\% 
  summarise(MLAS = mean(LAS)) \%>\% 
  ggplot(aes(yr, MLAS, group = rep)) +
  geom_line()
 
## Visualise trial by year
ggplot(larix, aes(x, y)) +
  geom_tile(aes(fill = LAS)) + 
  facet_wrap(~ yr)

## Correlations with environmental variables
if (require(GGally)) {
  ggpairs(larix[, c('map', 'mat', 'mi', 'LAS', 'DOS')])
}
}
