% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metagene-class.R
\name{read.metagene}
\alias{read.metagene}
\alias{metagene}
\alias{summary.metagene}
\alias{print.summary.metagene}
\alias{plot.metagene}
\alias{get_ntraits.metagene}
\alias{ngenerations.metagene}
\alias{nindividuals.metagene}
\alias{as.data.frame.metagene}
\title{Metagene Data Input}
\usage{
read.metagene(fname)

\method{summary}{metagene}(object, ...)

\method{print}{summary.metagene}(x, ...)

\method{plot}{metagene}(x, type = c("default", "spatial"), ...)

\method{get_ntraits}{metagene}(x, ...)

\method{ngenerations}{metagene}(x, ...)

\method{nindividuals}{metagene}(x, exclude.founders = FALSE, ...)

\method{as.data.frame}{metagene}(x, ..., exclude.founders = TRUE)
}
\arguments{
\item{fname}{file name of the second metagene output file (usually: 
insim.002)}

\item{object}{a metagene object}

\item{...}{not used}

\item{x}{a metagene object}

\item{type}{character. If 'default', the empirical density of the breeding
and phenotypic values will be represented by generation. If 'spatial', the
map of the spatial component will be plotted.}

\item{exclude.founders}{logical: should the data.frame contain the genetic
values of the founders?}
}
\value{
the data in the file as an object of class \code{metagene}

returns a data frame with one row per individual, with the spatial
  coordinates if applicable, the pedigree information, the generation, the
  true breeding value, the phenotype, the sex, the spatially structured
  component of the phenotype and other internal metagene variables.
}
\description{
A basic interface to the \href{http://www.igv.fi.cnr.it/noveltree/}{metagene}
simulator.

This function returns the data frame with the pedigree and phenotypes of the
simulated individuals.
}
\details{
Read the output file (the one with the pedigree. Usually: insim.002) of the 
Metagene program, and build an object of class metagene.
}
\section{Methods (by generic)}{
\itemize{
\item \code{summary}: summary of a metagene object

\item \code{print}: print summary method

\item \code{plot}: plots either genetic and phenotypic values, or the
spatial component of the phenotype. Pass further
\code{\link[ggplot2]{ggplot}} layers in ...

\item \code{get_ntraits}: gets the number of traits

\item \code{ngenerations}: gets the number of generations

\item \code{nindividuals}: gets the number of individuals

\item \code{as.data.frame}: Coerce to a data.frame
}}

\references{
\url{http://www.igv.fi.cnr.it/noveltree/}
}
