% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/variogram.R
\name{variogram}
\alias{variogram}
\alias{print.breedR.variogram}
\title{Empirical variograms of residuals}
\usage{
variogram(x, plot = c("all", "isotropic", "anisotropic", "perspective",
  "heat", "none"), R, coord, z)

\method{print}{breedR.variogram}(x, minN = 30, ...)
}
\arguments{
\item{x}{a \code{breedR} result.}

\item{plot}{character. What type of variogram is to be plotted. The default 
is 'all'. Other options are 'isotropic', 'heat', 'perspective' and 
'anisotropic'. See Details.}

\item{R}{numeric. Radius of the variogram}

\item{coord}{(optional) a two-column matrix with coordinates of observations}

\item{z}{(optional) a numeric vector of values to be represented spatially}

\item{minN}{numeric. Variogram values computed with less than \code{minN} 
pairs of observations are considered \emph{unstable} and therefore are not 
plotted. Default: 30.}

\item{...}{not used.}
}
\description{
Computes isotropic and anisotropic empirical variograms from the residuals of
a breedR model.
}
\details{
An empirical variogram computes the mean squared differences between 
observations separated by a vector \code{h}, for all possible \code{h}. An 
\code{isotropic} variogram assumes that the underlying process depends only 
on the (euclidean) \emph{distance} between points, but not on the orientation
or direction of \code{h}. At the other end, an \code{anisotropic} variogram 
assumes that the process might depend on the orientation, but not on the 
direction. Finally, \code{heat} and \code{perspective} are different 
representations of a variogram which assumes that the process depends only on
the absolute distance between rows and columns.

Unless \code{coord} or \code{z} are specified by the user, \code{variogram} 
builds the variogram with the residuals of the model fit in \code{x}. If 
\code{coord} or \code{z} are specified, then the spatial coordinates or the 
residuals are respectively overridden.

This function assumes that there is at most one observation per spatial 
location. Otherwise, are observations measured at different times? should a 
spatial-temporal variogram be fitted?
}
\section{Methods (by generic)}{
\itemize{
\item \code{print}: Print a breedR variogram
}}

\examples{
data(globulus)

# No spatial effect
res <- remlf90(fixed  = phe_X ~ 1,
               random = ~ gg,
               genetic = list(model = 'add_animal',
                              pedigree = globulus[, 1:3],
                              id = 'self'),
               data   = globulus)

Zd <- model.matrix(res)$genetic
PBV <- Zd \%*\% ranef(res)$genetic

# variogram() needs coordinates to compute distances
# either you use the \\code{coord} argument, or you do:
coordinates(res) <- globulus[, c('x', 'y')]

# there is residual autocorrelation
# there is also spatial structure in the Breeding Values
variogram(res)  
variogram(res, z = PBV)  

# Autoregressive spatial effect
# eliminates the residual autocorrelation
res.sp<- remlf90(fixed  = phe_X ~ 1,
                 spatial = list(model = 'AR', 
                                coord = globulus[, c('x', 'y')],
                                rho = c(.9, .9)),
                 genetic = list(model = 'add_animal',
                                pedigree = globulus[, 1:3],
                                id = 'self'),
                 data   = globulus)

Zd <- model.matrix(res.sp)$genetic
PBV <- Zd \%*\% ranef(res.sp)$genetic

variogram(res.sp)
variogram(res.sp, z = PBV)

  
}
\seealso{
\code{\link[fields]{vgram.matrix}}
}
